@@ -1,9 +1,9 @@
 package Sah::Schema::aos;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-02'; # DATE
+our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Collection'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 our $schema = [array => {
     summary => 'Array of (defined) strings',
@@ -14,13 +14,13 @@ The elements (strings) of the array must be defined.
 _
     of => ['str', {req=>1}, {}],
     examples => [
-        {data=>'a', valid=>0},
-        {data=>[], valid=>1},
-        {data=>{}, valid=>0},
-        {data=>['a'], valid=>1},
-        {data=>[undef], valid=>0},
-        {data=>['a', []], valid=>0},
-        {data=>[['a']], valid=>0},
+        {value=>'a', valid=>0},
+        {value=>[], valid=>1},
+        {value=>{}, valid=>0},
+        {value=>['a'], valid=>1},
+        {value=>[undef], valid=>0},
+        {value=>['a', []], valid=>0},
+        {value=>[['a']], valid=>0},
     ],
 }, {}];
 
@@ -39,25 +39,55 @@ Sah::Schema::aos - Array of (defined) strings
 
 =head1 VERSION
 
-This document describes version 0.005 of Sah::Schema::aos (from Perl distribution Sah-Schemas-Collection), released on 2020-03-02.
+This document describes version 0.006 of Sah::Schema::aos (from Perl distribution Sah-Schemas-Collection), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
+Using with L<Data::Sah>:
+
+ use Data::Sah qw(gen_validator);
+ my $vdr = gen_validator("aos*");
+ say $vdr->($data) ? "valid" : "INVALID!";
+
+ # Data::Sah can also create a validator to return error message, coerced value,
+ # even validators in other languages like JavaScript, from the same schema.
+ # See its documentation for more details.
+
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+
+ package MyApp;
+ our %SPEC;
+ $SPEC{myfunc} = {
+     v => 1.1,
+     summary => 'Routine to do blah ...',
+     args => {
+         arg1 => {
+             summary => 'The blah blah argument',
+             schema => ['aos*'],
+         },
+         ...
+     },
+ };
+ sub myfunc {
+     my %args = @_;
+     ...
+ }
+
 Sample data:
 
- "a"  # INVALID
+ undef  # INVALID
 
- []  # valid
+ undef  # valid
 
- {}  # INVALID
+ undef  # INVALID
 
- ["a"]  # valid
+ undef  # valid
 
- [undef]  # INVALID
+ undef  # INVALID
 
- ["a",[]]  # INVALID
+ undef  # INVALID
 
- [["a"]]  # INVALID
+ undef  # INVALID
 
 =head1 DESCRIPTION
 
