@@ -1,9 +1,9 @@
 package Sah::Schema::homs;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-02'; # DATE
+our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Collection'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 our $schema = [hash => {
     summary => 'Hash of maybe-strings',
@@ -12,13 +12,13 @@ our $schema = [hash => {
 _
     of => ['str', {}, {}],
     examples => [
-        {data=>'a', valid=>0},
-        {data=>[], valid=>0},
-        {data=>{}, valid=>1},
-        {data=>{k=>'a'}, valid=>1},
-        {data=>{k=>undef}, valid=>1},
-        {data=>{k=>'a', k2=>[]}, valid=>0},
-        {data=>{k=>'a', k2=>{}}, valid=>0},
+        {value=>'a', valid=>0},
+        {value=>[], valid=>0},
+        {value=>{}, valid=>1},
+        {value=>{k=>'a'}, valid=>1},
+        {value=>{k=>undef}, valid=>1},
+        {value=>{k=>'a', k2=>[]}, valid=>0},
+        {value=>{k=>'a', k2=>{}}, valid=>0},
     ],
 }, {}];
 
@@ -37,25 +37,55 @@ Sah::Schema::homs - Hash of maybe-strings
 
 =head1 VERSION
 
-This document describes version 0.005 of Sah::Schema::homs (from Perl distribution Sah-Schemas-Collection), released on 2020-03-02.
+This document describes version 0.006 of Sah::Schema::homs (from Perl distribution Sah-Schemas-Collection), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
+Using with L<Data::Sah>:
+
+ use Data::Sah qw(gen_validator);
+ my $vdr = gen_validator("homs*");
+ say $vdr->($data) ? "valid" : "INVALID!";
+
+ # Data::Sah can also create a validator to return error message, coerced value,
+ # even validators in other languages like JavaScript, from the same schema.
+ # See its documentation for more details.
+
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+
+ package MyApp;
+ our %SPEC;
+ $SPEC{myfunc} = {
+     v => 1.1,
+     summary => 'Routine to do blah ...',
+     args => {
+         arg1 => {
+             summary => 'The blah blah argument',
+             schema => ['homs*'],
+         },
+         ...
+     },
+ };
+ sub myfunc {
+     my %args = @_;
+     ...
+ }
+
 Sample data:
 
- "a"  # INVALID
+ undef  # INVALID
 
- []  # INVALID
+ undef  # INVALID
 
- {}  # valid
+ undef  # valid
 
- {k=>"a"}  # valid
+ undef  # valid
 
- {k=>undef}  # valid
+ undef  # valid
 
- {k=>"a",k2=>[]}  # INVALID
+ undef  # INVALID
 
- {k=>"a",k2=>{}}  # INVALID
+ undef  # INVALID
 
 =head1 DESCRIPTION
 
